@@ -18,9 +18,6 @@
    System headers sometimes define this.
    We just want to avoid a redefinition error message.  */
 
-#undef CAMSERV_VER_BUGFIX
-#undef CAMSERV_VER_MAJOR
-#undef CAMSERV_VER_MINOR
 #undef HAVE_JPEG_VALID
 
 
