@@ -4,7 +4,6 @@
 #include <stdarg.h>
 #include <signal.h>
 
-#include "camserv.h"
 #include "camconfig.h"
 #include "socket.h"
 #include "mainloop.h"
@@ -18,6 +17,8 @@ extern int errno;
 
 static int Abort = 0;
 
+#define MAX(x,y) ( (x) > (y) ? (x) : (y) )
+
 #define CINFO_STATE_PREAMBLE    0
 #define CINFO_STATE_PICTURE     1
 #define CINFO_STATE_SEPERATOR   2
@@ -34,8 +35,6 @@ static int Abort = 0;
 
 #define MODNAME "mainloop"
 
-#define MAX(x,y) (((x)>(y)) ? (x) : (y))
-
 typedef struct client_info_st {
   Socket *socket;           
   DataBuf *writebuf;
@@ -372,8 +371,7 @@ int main_loop( CamConfig *ccfg, Socket *picture_sock, char *picture_mem  ){
   SockSet *readset = NULL, *writeset = NULL;
   list_t *client_sockets;
   lnode_t *node;
-  int cfg_listen_port, highest_fd, picture_client_ready;
-  int num_sclients, num_clients;
+  int cfg_listen_port, highest_fd, num_clients, picture_client_ready;
   ClientInfo *clientinfo, *clientinfo2;
 
   if( (client_sockets = list_create( -1 )) == NULL)
@@ -422,7 +420,6 @@ int main_loop( CamConfig *ccfg, Socket *picture_sock, char *picture_mem  ){
   }
 
   num_clients = 0;
-  num_sclients = 0;
   picture_client_ready = 1;
 
   setup_signals();
@@ -431,8 +428,7 @@ int main_loop( CamConfig *ccfg, Socket *picture_sock, char *picture_mem  ){
     int sel_res, i, nset_socks;
     void **set_socks;
 
-    /* Only need to execute this if we have a streaming client */
-    if( (num_sclients > 0) && picture_client_ready == 1 ){
+    if( num_clients > 0 && picture_client_ready == 1 ){
       send( socket_query_fd( picture_sock ), "0", sizeof( "0" ), 0 );
       picture_client_ready = 0;
     }
@@ -460,6 +456,7 @@ int main_loop( CamConfig *ccfg, Socket *picture_sock, char *picture_mem  ){
 
       if( clientinfo->socket == listen_socket ) {
 	/* New client */
+
 	if( (new_cinfo = accept_client( listen_socket )) == NULL )
 	  continue;
 
@@ -491,13 +488,6 @@ int main_loop( CamConfig *ccfg, Socket *picture_sock, char *picture_mem  ){
 							  "max_bytes", 0 );
 	new_cinfo->max_frames  = camconfig_query_def_int( ccfg, SEC_SOCKET,
 							  "max_frames", 0 );
-
-	/* Send fresh request for a picture */
-	send( socket_query_fd( picture_sock ), "0", sizeof( "0" ), 0 );
-	picture_client_ready = 0;
-	/* Put this read socket on hold until the picture comes back */
-	sockset_hold( readset, new_cinfo->socket );	
-
       } else {
 	char cmdbuf[ 1024 ];
 	int readlen;
@@ -508,13 +498,10 @@ int main_loop( CamConfig *ccfg, Socket *picture_sock, char *picture_mem  ){
 	if( (readlen = read( socket_query_fd( clientinfo->socket), cmdbuf, 
 			     sizeof( cmdbuf ) - 1)) <= 0 )
 	{
-	  camserv_log( MODNAME, "Closing socket: %s", 
+	  camserv_log( MODNAME, "Closing socket :%s", 
 		       socket_query_remote_name( clientinfo->socket ));
 
-	  if (clientinfo->client_type == CLIENT_T_BROWSER ||
-	      clientinfo->client_type == CLIENT_T_PROXY) {
-	      num_sclients--;
-	  }
+	  
 	  client_remove( client_sockets, clientinfo );
 	  sockset_del_fd( readset, clientinfo->socket );
 	  sockset_unhold_all( writeset );
@@ -526,29 +513,24 @@ int main_loop( CamConfig *ccfg, Socket *picture_sock, char *picture_mem  ){
 	    if( dispatch_pictaker( cmdbuf, picture_mem ) == -1 )
 	      camserv_log( MODNAME, "Pictaker dispatch failure!");
 	    sockset_unhold_all( writeset );
-	    /* Release the read hold as the picture has now been taken */
-	    sockset_unhold_all( readset );
 	    picture_client_ready = 1;
 	  } else {
 	    /* Information from a regular client */
 	    cmdbuf[ readlen ] = '\0';
 	    if( clientinfo->client_type == CLIENT_T_UNINIT ) {
 	      char *preamble;
-	      size_t pre_size;
+	      int pre_size;
 
 	      /* Figure out what type of client we have */
 	      if( !strncmp( cmdbuf, "GET", 3 )) {
-		if( strstr( cmdbuf, "/singleframe" )) {
+		if( strstr( cmdbuf, "/singleframe" ))
 		  clientinfo->client_type = CLIENT_T_SINGLE;
-		} else {
+		else
 		  clientinfo->client_type = CLIENT_T_BROWSER;
-		  num_sclients++;
-	        }
 	      } else if( !strncmp( cmdbuf, "PROXY", 5 )) {
 		clientinfo->client_type = CLIENT_T_PROXY;
 		/* Here we are in the same state as being done writing a pic */
 		clientinfo->state       = CINFO_STATE_PICTURE;
-		num_sclients++;	
 		databuf_buf_set( clientinfo->writebuf, NULL, 0 ); 
 	      } else 
 		clientinfo->client_type = CLIENT_T_BROWSER;
@@ -569,11 +551,11 @@ int main_loop( CamConfig *ccfg, Socket *picture_sock, char *picture_mem  ){
   		  camserv_log( MODNAME, "Failed to add socket %d to write set!",
 			   socket_query_fd( clientinfo->socket ));
 	      }
-	  } 
-	} 
-      } 
-    } 
-  } 
+	    }
+	  }
+	}
+      }
+    }
 
     if( set_socks != NULL ) free( set_socks );
 
@@ -595,10 +577,6 @@ int main_loop( CamConfig *ccfg, Socket *picture_sock, char *picture_mem  ){
 	    camserv_log( MODNAME, "Databuf write error on socket: %s\n",
 			 socket_query_remote_name( cinfo->socket ));
 	  
-	  if (cinfo->client_type == CLIENT_T_BROWSER) {
-	      num_sclients--;
-	  }
-
 	  client_remove( client_sockets, cinfo );
 	  sockset_del_fd( readset, cinfo->socket );
 	  sockset_del_fd( writeset, cinfo->socket );
@@ -609,11 +587,6 @@ int main_loop( CamConfig *ccfg, Socket *picture_sock, char *picture_mem  ){
 	if( write_proxy_client( cinfo, writeset ) == -1 ){
 	  camserv_log( MODNAME, "Databuf write error on socket: %d",
 		   socket_query_fd( cinfo->socket ));
-
-	  /* Should be proxy, but better check */
-	  if (cinfo->client_type == CLIENT_T_PROXY) {
-	      num_sclients--;
-	  }
 	  client_remove( client_sockets, cinfo );
 	  sockset_del_fd( readset, cinfo->socket );
 	  sockset_del_fd( writeset, cinfo->socket );
