@@ -1,6 +1,6 @@
 /*  camserv - An internet streaming picture application
  *
- *  Copyright (C) 1999-2002  Jon Travis (jtravis@p00p.org)
+ *  Copyright (C) 1999  Jon Travis (jon@dsndata.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,17 +24,16 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <sys/mman.h>
+#include <sys/time.h>
 #include <sys/ioctl.h>
 #include <signal.h>
 #include <math.h>
 #include <string.h>
 
 #include <linux/videodev.h>
-#include "camserv.h"
 #include "video.h"
 #include "log.h"
 #include "grafxmisc.h"
-#include "yuv2rgb.h"
 
 #define SYNC_FAILURE_ALARM 1
 
@@ -73,10 +72,6 @@
 #define V4L_DEF_AUTOBRIGHT 0
 #define V4L_DEF_BRIGHTMEAN 128
 
-#define V4L_BRIGHT_AUTO_INCREMENT     500
-#define V4L_BRIGHT_MIN                0
-#define V4L_BRIGHT_MAX                60000
-
 #define MODNAME "v4l"
 
 typedef struct video_v4l_st {
@@ -335,7 +330,7 @@ int setup_video_channel( Video_V4L *v4l_dev, CamConfig *ccfg ){
     v4l_dev->brightmean = camconfig_query_def_int( ccfg, v4l_dev->section_name,
 						   V4LMOD_BRIGHTMEAN,
 						   V4L_DEF_BRIGHTMEAN );
-    newmean = clip_to(v4l_dev->brightmean, 0, 255 );
+    newmean = MAX( MIN( 255, v4l_dev->brightmean ), 0 );
     if( v4l_dev->brightmean != newmean  ){
       camserv_log( MODNAME, "%s clamped to a value of %d (0-255)",
 		   V4LMOD_BRIGHTMEAN, newmean );
@@ -347,10 +342,10 @@ int setup_video_channel( Video_V4L *v4l_dev, CamConfig *ccfg ){
     x2 = camconfig_query_def_int(ccfg,v4l_dev->section_name,V4LMOD_BRIGHTX2,0);
     y2 = camconfig_query_def_int(ccfg,v4l_dev->section_name,V4LMOD_BRIGHTY2,0);
     
-    v4l_dev->brightx1 = clip_to(x1, 0, v4l_dev->width);
-    v4l_dev->brighty1 = clip_to(y1, 0, v4l_dev->height);
-    v4l_dev->brightx2 = clip_to(x2, 0, v4l_dev->width);
-    v4l_dev->brighty2 = clip_to(y2, 0, v4l_dev->height);
+    v4l_dev->brightx1 = MAX( MIN( v4l_dev->width,  x1 ), 0 );
+    v4l_dev->brighty1 = MAX( MIN( v4l_dev->height, y1 ), 0 );
+    v4l_dev->brightx2 = MAX( MIN( v4l_dev->width,  x2 ), 0 );
+    v4l_dev->brighty2 = MAX( MIN( v4l_dev->height, y2 ), 0 );
     if( v4l_dev->brightx2 < v4l_dev->brightx1 ||
 	v4l_dev->brighty2 < v4l_dev->brighty1 ){
       camserv_log( MODNAME, "Disabling autobrightness!  (reversed coords)");
@@ -403,15 +398,13 @@ int setup_video_channel( Video_V4L *v4l_dev, CamConfig *ccfg ){
 
   /* If this channel is tunable, then we need to go ahead and
      set the frequency */
-  if(cfg_frequency != 0){
-    if(!(v4l_dev->vidchan.flags & VIDEO_VC_TUNER) ){
-      camserv_log( MODNAME, "Invalid frequency!  (Channel has no tuner!)" );
-    } else {
-      frequency = cfg_frequency * 16;
-      if( ioctl (v4l_dev->video_fd, VIDIOCSFREQ, &frequency ) == -1 ){
-	perror( "(V4L) Frequency Setting" );
-	/* Excusable error */
-      }
+  if( cfg_frequency != 0 && !(v4l_dev->vidchan.flags & VIDEO_VC_TUNER) ){
+    camserv_log( MODNAME, "Invalid frequency!  (Channel has no tuner!)" );
+  } else {
+    frequency = cfg_frequency * 16;
+    if( ioctl (v4l_dev->video_fd, VIDIOCSFREQ, &frequency ) == -1 ){
+      perror( "(V4L) Frequency Setting" );
+      /* Excusable error */
     }
   }
 
@@ -484,10 +477,10 @@ int video_init( Video_V4L *v4l_dev, CamConfig *ccfg ){
   cfg_height = camconfig_query_def_int( ccfg, SEC_VIDEO,
 					V4LMOD_HEIGHT, V4L_DEF_HEIGHT );
   
-  v4l_dev->vidwin.width = clip_to(cfg_width, v4l_dev->vidcaps.minwidth,
-                                  v4l_dev->vidcaps.maxwidth );
-  v4l_dev->vidwin.height = clip_to(cfg_height, v4l_dev->vidcaps.minheight, 
-                                   v4l_dev->vidcaps.maxheight);
+  v4l_dev->vidwin.width = MAX( MIN( v4l_dev->vidcaps.maxwidth, cfg_width),
+			       v4l_dev->vidcaps.minwidth );
+  v4l_dev->vidwin.height = MAX(MIN(v4l_dev->vidcaps.maxheight, cfg_height),
+			       v4l_dev->vidcaps.minheight);
 
   v4l_dev->vidwin.clipcount = 0;
   v4l_dev->vidwin.flags = 0;
@@ -499,13 +492,6 @@ int video_init( Video_V4L *v4l_dev, CamConfig *ccfg ){
     return -1;
   }
 
-  camserv_log("video_init","image width: default:%d max:%d min:%d config:%d used:%d\n",
-        V4L_DEF_WIDTH, v4l_dev->vidcaps.maxwidth, v4l_dev->vidcaps.minwidth,
-        cfg_width, v4l_dev->vidwin.width);
-  camserv_log("video_init","image height: default:%d max:%d min:%d config:%d used:%d\n",
-        V4L_DEF_HEIGHT, v4l_dev->vidcaps.maxheight, v4l_dev->vidcaps.minheight,
-        cfg_height, v4l_dev->vidwin.height);
-
   v4l_dev->width = v4l_dev->vidwin.width;
   v4l_dev->height = v4l_dev->vidwin.height;
 
@@ -527,29 +513,13 @@ int video_init( Video_V4L *v4l_dev, CamConfig *ccfg ){
   
     v4l_dev->vidmmap.height = v4l_dev->height;
     v4l_dev->vidmmap.width = v4l_dev->width;
-
-    if(ioctl(v4l_dev->video_fd, VIDIOCGPICT, &v4l_dev->vidpict) == -1){
-      perror("(V4L) Picture capabilities fetch");
-      return -1;
-    } else {
-      if(v4l_dev->vidpict.palette == VIDEO_PALETTE_YUV420P){
-	v4l_dev->vidmmap.format = VIDEO_PALETTE_YUV420P;
-	yuv2rgb_init();
-      } else {
-	v4l_dev->vidmmap.format = VIDEO_PALETTE_RGB24;
-      }
-    }
+    v4l_dev->vidmmap.format = VIDEO_PALETTE_RGB24;
     v4l_dev->current_frame = 0;
   
     for( i=0; i< v4l_dev->vidmbuf.frames; i++ ){
       v4l_dev->vidmmap.frame = i;
-      if(ioctl(v4l_dev->video_fd, VIDIOCMCAPTURE, &v4l_dev->vidmmap ) == -1 ) {
-        camserv_log( MODNAME, "Failed with RGB, trying YUV420P");
-        v4l_dev->vidmmap.format = VIDEO_PALETTE_YUV420P;
-
-        if(ioctl(v4l_dev->video_fd, VIDIOCMCAPTURE, &v4l_dev->vidmmap ) == -1 )
-          perror( "(V4L) Filling capture frames" );
-      }
+      if(ioctl(v4l_dev->video_fd, VIDIOCMCAPTURE, &v4l_dev->vidmmap ) == -1 )
+	perror( "(V4l) Filling capture frames" );
     }
     v4l_dev->vidmmap.frame = 0;
     v4l_dev->uses_mbuf = 1;
@@ -650,8 +620,8 @@ adjust_bright( int width, int height, const char *addr, int is_rgb,
       --v4l_dev->autoleft > 0 ) 
     return 0;
 
-  totmean = camserv_get_pic_mean( width, height, addr, is_rgb, 0, 0,
-				  width, height );
+  totmean = calculate_pic_mean( width, height, addr, is_rgb, 0, 0,
+				width, height );
   adjust = 0;
 
   if( totmean < v4l_dev->brightmean - 10 || 
@@ -659,10 +629,9 @@ adjust_bright( int width, int height, const char *addr, int is_rgb,
 
     newbright = v4l_dev->vidpict.brightness;
     if( totmean > v4l_dev->brightmean) 
-      newbright -= V4L_BRIGHT_AUTO_INCREMENT;
+      newbright -= 500;
     else
-      newbright += V4L_BRIGHT_AUTO_INCREMENT;
-    newbright = clip_to(newbright, V4L_BRIGHT_MIN, V4L_BRIGHT_MAX);
+      newbright += 500;
     adjust = 1;
   }
 
@@ -679,68 +648,6 @@ adjust_bright( int width, int height, const char *addr, int is_rgb,
   }
 }
 
-
-/* 
-   functions ripped from xawtv source (v3.56): libng/color_yuv2rgb.c
-   and slightly modified
-*/
-
-/* name in xawtv source: ng_color_yuv2rgb_init() */
-static void yuv2rgb_init(void){
-    int i;
-    
-    /* init Lookup tables */
-    for (i = 0; i < 256; i++) {
-        ng_yuv_gray[i] = i * LUN_MUL >> 8;
-        ng_yuv_red[i]  = (RED_ADD    + i * RED_MUL)    >> 8;
-        ng_yuv_blue[i] = (BLUE_ADD   + i * BLUE_MUL)   >> 8;
-        ng_yuv_g1[i]   = (GREEN1_ADD + i * GREEN1_MUL) >> 8;
-        ng_yuv_g2[i]   = (GREEN2_ADD + i * GREEN2_MUL) >> 8;
-    }
-    for (i = 0; i < CLIP; i++)
-        ng_clip[i] = 0;
-    for (; i < CLIP + 256; i++)
-        ng_clip[i] = i - CLIP;
-    for (; i < 2 * CLIP + 256; i++)
-        ng_clip[i] = 255;
-}
-
-/* name in xawtv source: yuv420p_to_rgb24() */
-static void   
-yuv2rgb (char *out_addr, char *in_addr, int rowstride, int width, int height)
-{
-    unsigned char *y,*u,*v;
-    unsigned char *us,*vs;
-    unsigned char *dp,*d;
-    int i,j,gray;
-
-    dp = (unsigned char *)out_addr;
-    y  = (unsigned char *)in_addr;
-    u  = y + width * height;
-    v  = u + width * height / 4;
-
-    for (i = 0; i < height; i++) {
-        d = dp;
-        us = u; vs = v;
-        for (j = 0; j < width; j+= 2) {
-            gray   = GRAY(*y);
-            *(d++) = RED(gray,*v);
-            *(d++) = GREEN(gray,*v,*u);
-            *(d++) = BLUE(gray,*u);
-            y++;
-            gray   = GRAY(*y);
-            *(d++) = RED(gray,*v);
-            *(d++) = GREEN(gray,*v,*u);
-            *(d++) = BLUE(gray,*u);
-            y++; u++; v++;
-        }
-        if (0 == (i % 2)) {
-            u = us; v = vs;
-        }
-        dp += rowstride;
-    }
-}
-
 static void
 bgr2rgb (char *out_addr, char *in_addr, int rowstride, int width, int height)
 {
@@ -776,17 +683,12 @@ int mbuf_snapshot( Video_V4L *vid_dev, char *place_buffer ){
   }
   alarm( 0 );
 
-  if(vid_dev->vidmmap.format == VIDEO_PALETTE_YUV420P){
-      yuv2rgb( place_buffer,
-	       vid_dev->video_buffer + 
-	       vid_dev->vidmbuf.offsets[ vid_dev->current_frame ],
-	       vid_dev->width * 3, vid_dev->width, vid_dev->height );
-  } else {
-      bgr2rgb( place_buffer,
-	       vid_dev->video_buffer + 
-	       vid_dev->vidmbuf.offsets[ vid_dev->current_frame ],
-	       vid_dev->width * 3, vid_dev->width, vid_dev->height );
-  }
+  bgr2rgb( place_buffer,
+	   vid_dev->video_buffer + 
+	   vid_dev->vidmbuf.offsets[ vid_dev->current_frame ],
+	   vid_dev->width * 3, vid_dev->width, vid_dev->height );
+
+
 
   if( ioctl( vid_dev->video_fd, VIDIOCMCAPTURE, &vid_dev->vidmmap ) == -1 ){
     perror( "VIDIOCMCAPTURE" );
