@@ -13,18 +13,17 @@
  * The copyright extends to translations of this work into other languages,
  * including machine languages. 
  *
- * $Id: hash.c,v 1.1.1.3 2002/03/11 00:51:44 bap Exp $
- * $Name: upstream_version_0_5_1 $
+ * $Id: hash.c,v 1.1 1999/11/05 00:23:27 jtravis Exp $
+ * $Name:  $
  */
 
 #include <stdlib.h>
 #include <stddef.h>
 #include <assert.h>
-#include <string.h>
 #define HASH_IMPLEMENTATION
 #include "hash.h"
 
-static const char rcsid[] = "$Id: hash.c,v 1.1.1.3 2002/03/11 00:51:44 bap Exp $";
+static const char rcsid[] = "$Id: hash.c,v 1.1 1999/11/05 00:23:27 jtravis Exp $";
 static const char right[] = "Copyright (C) 1997 Kaz Kylheku";
 
 #define INIT_BITS	6
