@@ -13,8 +13,8 @@
  * The copyright extends to translations of this work into other languages,
  * including machine languages. 
  *
- * $Id: list.c,v 1.1.1.3 1999/11/05 00:23:21 bap Exp $
- * $Name: upstream_version_0_5_1 $
+ * $Id: list.c,v 1.1 1999/11/05 00:23:21 jtravis Exp $
+ * $Name:  $
  */
 
 
@@ -30,7 +30,7 @@
 #define lnode_next(N)		((N)->next)
 #define lnode_prev(N)		((N)->prev)
 
-static const char rcsid[] = "$Id: list.c,v 1.1.1.3 1999/11/05 00:23:21 bap Exp $";
+static const char rcsid[] = "$Id: list.c,v 1.1 1999/11/05 00:23:21 jtravis Exp $";
 static const char right[] = "Copyright (C) 1997 Kaz Kylheku";
 
 /*
