@@ -1,8 +1,8 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdarg.h>
+#include <sys/time.h>
 
-#include "camserv.h"
 #include "log.h"
 
 void camserv_log( const char *module, const char *pattern, ... ){
@@ -17,9 +17,8 @@ void camserv_log( const char *module, const char *pattern, ... ){
 
   time( &curtime );
   loctime = *localtime( &curtime );
-  sprintf( timebuf, "%4d-%02d-%02d %02d:%02d:%02d", 
-	   loctime.tm_year + 1900, loctime.tm_mon + 1, loctime.tm_mday, 
-	   loctime.tm_hour, loctime.tm_min, loctime.tm_sec );
+  sprintf( timebuf, "%02d-%02d %02d:%02d", loctime.tm_mon + 1, 
+	   loctime.tm_mday, loctime.tm_hour, loctime.tm_min );
 
   fprintf( stderr, "%s [%s] %s\n", timebuf, module, decent_buffer );
 }
