@@ -1,6 +1,6 @@
 /*  camserv - An internet streaming picture application
  *
- *  Copyright (C) 1999-2002  Jon Travis (jtravis@p00p.org)
+ *  Copyright (C) 1999  Jon Travis (jon@dsndata.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "camserv_config.h"
+#include "config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -340,11 +340,8 @@ void set_client_writebuf( ClientData *cldata  ){
     len = 0;
     cldata->proxycldata.proxystate = PROXYCLSTATE_SEND_PICTURE;
     cldata->proxycldata.management_data = NULL;
-  } else {
+  } else 
     camserv_log( MODNAME, "Unknown client state: \"%d\"", cldata->clienttype );
-    cp = "";
-    len = 0;
-  }
 
   databuf_buf_set( cldata->writebuf, cp, len );
 }
@@ -626,7 +623,7 @@ int main( int argc, char *argv[] ){
   struct timeval retry_time;
 
   if( argc < 3 ) {
-    fprintf( stderr, "camserv relay v%s - by Jon Travis (jtravis@p00p.org)\n",
+    fprintf( stderr, "camserv relay v%s - by Jon Travis (jon@dsndata.com)\n",
 	     VERSION );
     fprintf( stderr, "Syntax: %s <port> <camserv IP> <ccamserv port>\n", 
 	     argv[ 0 ]);
